#!/usr/bin/env bash

# Processes a list of CSE air-gapped containers.
# Usage ./getting_started.sh [dependency list file name] [Target registry]


process_auxiliary_dependencies() {
	# Reads in a file with list of containers, pulls them and pushes them to target registry
	# Usage process_auxiliary_dependencies [dependency list file name] [Target registry]

	local target_registry_aux=$2
	while read -r line || [ -n "$line" ];
	do
		if [[ "$line" == \#* ]] ||  [[ "$line" == " *" ]] || [[ "$line" == "" ]] ;
		then
			continue
		fi
		local source_registry_aux=$(echo $line | cut -d' ' -f 1)
		local image_name_aux=$(echo $line | cut -d' ' -f 2)
		local image_tag_aux=$(echo $line | cut -d' ' -f 3)
		local image_tag_no_sha_aux=$(echo $image_tag_aux | cut -d'@' -f 1)
		local vmware_cloud_director_project='vmware-cloud-director'
		docker pull $source_registry_aux/$image_name_aux:$image_tag_aux
		docker tag $source_registry_aux/$image_name_aux:$image_tag_aux \
			$target_registry_aux/$vmware_cloud_director_project/$image_name_aux:$image_tag_no_sha_aux
		docker push $target_registry_aux/$vmware_cloud_director_project/$image_name_aux:$image_tag_no_sha_aux
	done < $1
}

function process_airgapped_container() {
	# Takes in location of a container image and Target registry. Pulls
	# the image, pushes the image to target registry. Expands the container
	# image to get access to the list of images that this arigapped image
	# depends on, pulls them from source registry and pushes them to target
	# registry.

	# Usage process_airgapped_container [Source registry] [image name] [image tag] [Target registry]

	cwd=$(pwd)

	local source_registry_airgap=$1
	local image_name_airgap=$2
	local image_tag_airgap=$3
	local image_tag_no_sha_airgap=$(echo $image_tag_airgap | cut -d'@' -f 1)
	local target_registry_airgap=$4

	docker pull $source_registry_airgap/$image_name_airgap:$image_tag_airgap
	docker tag $source_registry_airgap/$image_name_airgap:$image_tag_airgap \
		$target_registry_airgap/$image_name_airgap:$image_tag_no_sha_airgap
	docker push $target_registry_airgap/$image_name_airgap:$image_tag_no_sha_airgap
	docker create --name "temp_container" $target_registry_airgap/$image_name_airgap:$image_tag_no_sha_airgap
	docker export "temp_container" -o container_fs.tar
	docker container rm "temp_container"

	mkdir -p container_fs
	rm -rf container_fs/*

	tar -xvf container_fs.tar -C container_fs

	cd container_fs/src/artifact
	process_auxiliary_dependencies "dependencies.txt" $target_registry_airgap

	cd $cwd
	rm -rf container_fs
	rm -f container_fs.tar
}


if [[ "$#" != 2 ]];
then
	echo "Usage ./getting_started.sh [filename containing a list of CSE air-gapped containers] [target registry]"
	exit 1
fi

set -e

target_registry=$2
while read -r line || [ -n "$line" ];
do
	if [[ "$line" == \#* ]] ||  [[ "$line" == " *" ]] || [[ "$line" == "" ]];
	then
		continue
	fi
	source_registry=$(echo $line | cut -d' ' -f 1)
	image_name=$(echo $line | cut -d' ' -f 2)
	image_tag=$(echo $line | cut -d' ' -f 3)

	process_airgapped_container $source_registry $image_name $image_tag $target_registry
done < $1
